import { jsxs as _jsxs, Fragment as _Fragment, jsx as _jsx } from "@emotion/react/jsx-runtime";
import { useState } from "react";
import { useDispatch } from "react-redux";
import { createRoot } from 'react-dom/client';
import { Box, Button, ButtonGroup } from '@primer/react';
import Jupyter from './jupyter/Jupyter';
import { useJupyter } from './jupyter/JupyterContext';
import Kernel from './jupyter/services/kernel/Kernel';
import Cell from './components/cell/Cell';
import { selectCell, cellActions } from './components/cell/CellState';
import Notebook from './components/notebook/Notebook';
import { notebookActions } from './components/notebook/NotebookState';
import CellSidebarDefault from './components/notebook/cell/sidebar/CellSidebarDefault';
import Output from "./components/outputs/Output";
import "./../style/index.css";
const SOURCE_IPYWIDGET = `import ipywidgets as widgets
widgets.IntSlider(
    value=7,
    min=0,
    max=10,
    step=1
)`;
const CellPreview = () => {
    const cell = selectCell();
    return (_jsxs(_Fragment, { children: [_jsxs("div", { children: ["source: ", cell.source] }, void 0),
            _jsxs("div", { children: ["kernel available: ", String(cell.kernelAvailable)] }, void 0)] }, void 0));
};
const CellToolbar = () => {
    const cell = selectCell();
    const dispatch = useDispatch();
    return (_jsxs(_Fragment, { children: [_jsx(Box, Object.assign({ display: "flex" }, { children: _jsxs(ButtonGroup, { children: [_jsx(Button, Object.assign({ variant: "default", size: "small", onClick: () => dispatch(cellActions.execute()) }, { children: "Run the cell" }), void 0),
                        _jsx(Button, Object.assign({ variant: "outline", size: "small", onClick: () => dispatch(cellActions.outputsCount(0)) }, { children: "Reset outputs count" }), void 0)] }, void 0) }), void 0),
            _jsxs(Box, { children: ["Outputs count: ", cell.outputsCount] }, void 0)] }, void 0));
};
const NotebookToolbar = () => {
    const dispatch = useDispatch();
    return (_jsx(_Fragment, { children: _jsx(Box, Object.assign({ display: "flex" }, { children: _jsxs(ButtonGroup, { children: [_jsx(Button, Object.assign({ variant: "default", size: "small", onClick: () => dispatch(notebookActions.save.started(undefined)) }, { children: "Save the notebook" }), void 0),
                    _jsx(Button, Object.assign({ variant: "default", size: "small", onClick: () => dispatch(notebookActions.runAll.started()) }, { children: "Run all" }), void 0)] }, void 0) }), void 0) }, void 0));
};
const OutputExample = () => {
    const { baseUrl, wsUrl } = useJupyter();
    const [kernel,] = useState(new Kernel({ baseUrl, wsUrl }));
    return (_jsx(Output, { showEditor: true, autoRun: true, kernel: kernel, code: SOURCE_IPYWIDGET }, void 0));
};
const div = document.createElement('div');
document.body.appendChild(div);
const root = createRoot(div);
root.render(_jsxs(Jupyter, { children: [_jsx(CellPreview, {}, void 0),
        _jsx(CellToolbar, {}, void 0),
        _jsx(Cell, {}, void 0),
        _jsx("hr", {}, void 0),
        _jsx(OutputExample, {}, void 0),
        _jsx("hr", {}, void 0),
        _jsx(NotebookToolbar, {}, void 0),
        _jsx(Notebook, { path: "test.ipynb", CellSidebar: CellSidebarDefault }, void 0)] }, void 0));
//# sourceMappingURL=JupyterExample.js.map