import { jsx as _jsx, Fragment as _Fragment } from "@emotion/react/jsx-runtime";
import { useState, useEffect } from 'react';
import { useDispatch } from "react-redux";
import { CodeCell } from '@jupyterlab/cells';
import { useJupyter } from './../../jupyter/JupyterContext';
import LuminoAttached from '../../jupyter/lumino/LuminoAttached';
import { cellActions } from './CellState';
import CellAdapter from './CellAdapter';
import '@jupyterlab/application/style/index.css';
import '@jupyterlab/codemirror/style/index.css';
import '@jupyterlab/cells/style/index.css';
import '@jupyterlab/theme-light-extension/style/theme.css'; // This should be only index.css, looks like jupyterlab has a regression here...
import '@jupyterlab/theme-light-extension/style/variables.css';
import '@jupyterlab/completer/style/index.css';
import './Cell.css';
const DEFAULT_SOURCE = `from IPython.display import display

for i in range(10):
    display('String {} added to the DOM in separated DIV.'.format(i))`;
export const Cell = (props) => {
    const { source, autoStart } = props;
    const { serviceManager } = useJupyter();
    const dispatch = useDispatch();
    const [adapter, setAdapter] = useState();
    useEffect(() => {
        if (serviceManager) {
            const adapter = new CellAdapter(source, serviceManager);
            dispatch(cellActions.update({ adapter }));
            dispatch(cellActions.source(props.source));
            adapter.codeCell.model.value.changed.connect((sender, changedArgs) => {
                dispatch(cellActions.source(sender.text));
            });
            adapter.codeCell.outputArea.outputLengthChanged.connect((outputArea, outputsCount) => {
                dispatch(cellActions.outputsCount(outputsCount));
            });
            adapter.sessionContext.initialize().then(() => {
                if (autoStart) {
                    const execute = CodeCell.execute(adapter.codeCell, adapter.sessionContext);
                    execute.then((msg) => {
                        dispatch(cellActions.update({
                            kernelAvailable: true,
                        }));
                    });
                }
            });
            setAdapter(adapter);
        }
    }, [source, serviceManager]);
    return adapter ? _jsx(LuminoAttached, { children: adapter.panel }, void 0) : _jsx(_Fragment, { children: "Loading..." }, void 0);
};
Cell.defaultProps = {
    source: DEFAULT_SOURCE,
    autoStart: true,
};
export default Cell;
//# sourceMappingURL=Cell.js.map