import { useSelector } from "react-redux";
import actionCreatorFactory from "typescript-fsa";
import { combineEpics } from "redux-observable";
import { reducerWithInitialState } from "typescript-fsa-reducers";
import { ignoreElements, map, tap } from "rxjs/operators";
import { ofAction } from "@datalayer/typescript-fsa-redux-observable";
import { NotebookActions } from "@jupyterlab/notebook";
import { cmdIds } from "./NotebookCommands";
export const notebookInitialState = {
    model: undefined,
    activeCell: undefined,
    kernelStatus: undefined,
    notebookChange: undefined,
    portals: [],
    adapter: undefined,
    saveRequest: undefined,
};
/* Selectors */
export const selectNotebook = () => useSelector((state) => {
    if (state.notebook) {
        return state.notebook;
    }
    return notebookInitialState;
});
export const selectNotebookModel = () => useSelector((state) => {
    if (state.notebook) {
        return state.notebook.model;
    }
    return notebookInitialState.model;
});
export const selectActiveCell = () => useSelector((state) => {
    if (state.notebook) {
        return state.notebook.activeCell;
    }
    return notebookInitialState.activeCell;
});
export const selectNotebookPortals = () => useSelector((state) => {
    if (state.notebook) {
        return state.notebook.portals;
    }
    return notebookInitialState.portals;
});
export const selectSaveRequest = () => useSelector((state) => {
    if (state.notebook) {
        return state.notebook.saveRequest;
    }
    return notebookInitialState.saveRequest;
});
export const selectNotebookPortal = () => useSelector((state) => {
    if (state.notebook) {
        return state.notebook.portal;
    }
    return notebookInitialState.portal;
});
/* Actions */
export var ActionType;
(function (ActionType) {
    ActionType["RESET"] = "notebook/RESET";
    ActionType["UPDATE"] = "notebook/UPDATE";
    ActionType["NOTEBOOK_CHANGE"] = "notebook/NOTEBOOK_CHANGE";
    ActionType["MODEL_CHANGE"] = "notebook/MODEL_CHANGE";
    ActionType["ACTIVE_CELL_CHANGE"] = "notebook/ACTIVE_CELL_CHANGE";
    ActionType["KERNEL_STATUS_CHANGE"] = "notebook/KERNEL_STATUS_CHANGE";
    ActionType["RUN"] = "notebook/RUN";
    ActionType["RUN_ALL"] = "notebook/RUN_ALL";
    ActionType["SAVE"] = "notebook/SAVE";
    ActionType["INTERRUPT"] = "notebook/INTERRUPT";
    ActionType["INSERT_ABOVE"] = "notebook/INSERT_ABOVE";
    ActionType["INSERT_BELOW"] = "notebook/INSERT_BELOW";
    ActionType["DELETE"] = "notebook/DELETE";
    ActionType["PORTAL"] = "notebook/PORTAL";
    ActionType["SET_PORTALS"] = "notebook/SET_PORTALS";
    ActionType["CHANGE_CELL_TYPE"] = "notebook/CHANGE_CELL_TYPE";
    ActionType["SET_PORTAL"] = "notebook/SET_PORTAL";
})(ActionType || (ActionType = {}));
const actionCreator = actionCreatorFactory('jupyterNotebook');
export const notebookActions = {
    reset: actionCreator(ActionType.RESET),
    update: actionCreator(ActionType.UPDATE),
    notebookChange: actionCreator(ActionType.NOTEBOOK_CHANGE),
    modelChange: actionCreator(ActionType.MODEL_CHANGE),
    activeCellChange: actionCreator(ActionType.ACTIVE_CELL_CHANGE),
    kernelStatusChanged: actionCreator(ActionType.KERNEL_STATUS_CHANGE),
    portal: actionCreator(ActionType.PORTAL),
    setPortals: actionCreator(ActionType.SET_PORTALS),
    setPortal: actionCreator(ActionType.SET_PORTAL),
    save: actionCreator.async(ActionType.SAVE),
    run: actionCreator.async(ActionType.RUN),
    runAll: actionCreator.async(ActionType.RUN_ALL),
    interrupt: actionCreator.async(ActionType.INTERRUPT),
    insertAbove: actionCreator.async(ActionType.INSERT_ABOVE),
    insertBelow: actionCreator.async(ActionType.INSERT_BELOW),
    delete: actionCreator.async(ActionType.DELETE),
    changeCellType: actionCreator.async(ActionType.CHANGE_CELL_TYPE)
};
/* Epics */
const runEpic = (action$, state$) => action$.pipe(ofAction(notebookActions.run.started), tap(action => {
    var _a, _b;
    (_b = (_a = state$.value.notebook) === null || _a === void 0 ? void 0 : _a.adapter) === null || _b === void 0 ? void 0 : _b.commands.execute(cmdIds.run);
}), ignoreElements());
const runAllEpic = (action$, state$) => action$.pipe(ofAction(notebookActions.runAll.started), tap(action => {
    var _a, _b;
    (_b = (_a = state$.value.notebook) === null || _a === void 0 ? void 0 : _a.adapter) === null || _b === void 0 ? void 0 : _b.commands.execute(cmdIds.runAll);
}), ignoreElements());
const interruptEpic = (action$, state$) => action$.pipe(ofAction(notebookActions.interrupt.started), tap(action => {
    var _a, _b;
    (_b = (_a = state$.value.notebook) === null || _a === void 0 ? void 0 : _a.adapter) === null || _b === void 0 ? void 0 : _b.commands.execute(cmdIds.interrupt);
}), ignoreElements());
const insertAboveEpic = (action$, state$) => action$.pipe(ofAction(notebookActions.insertAbove.started), tap(action => {
    state$.value.notebook.adapter.setDefaultCellType(action.payload);
    state$.value.notebook.adapter.commands.execute(cmdIds.insertAbove);
}), ignoreElements());
const insertBelowEpic = (action$, state$) => action$.pipe(ofAction(notebookActions.insertBelow.started), tap(action => {
    var _a, _b;
    state$.value.notebook.adapter.setDefaultCellType(action.payload);
    (_b = (_a = state$.value.notebook) === null || _a === void 0 ? void 0 : _a.adapter) === null || _b === void 0 ? void 0 : _b.commands.execute(cmdIds.insertBelow);
}), ignoreElements());
const deleteEpic = (action$, state$) => action$.pipe(ofAction(notebookActions.delete.started), tap(action => {
    var _a, _b;
    (_b = (_a = state$.value.notebook) === null || _a === void 0 ? void 0 : _a.adapter) === null || _b === void 0 ? void 0 : _b.commands.execute(cmdIds.deleteCells);
}), ignoreElements());
const changeCellTypeEpic = (action$, state$) => action$.pipe(ofAction(notebookActions.changeCellType.started), tap(action => {
    var _a, _b, _c;
    //      state$.value.notebook?.adapter?.changeCellType(action.payload);
    //      state$.value.notebook?.adapter?.commands.execute(cmdIds.toCode);
    NotebookActions.changeCellType((_c = (_b = (_a = state$.value.notebook) === null || _a === void 0 ? void 0 : _a.adapter) === null || _b === void 0 ? void 0 : _b.notebookPanel) === null || _c === void 0 ? void 0 : _c.content, action.payload);
}), ignoreElements());
const saveEpic = (action$, state$) => action$.pipe(ofAction(notebookActions.save.started), map(action => {
    var _a, _b;
    if (action.payload === undefined) {
        (_b = (_a = state$.value.notebook) === null || _a === void 0 ? void 0 : _a.adapter) === null || _b === void 0 ? void 0 : _b.commands.execute(cmdIds.save);
    }
    return notebookActions.save.done({
        params: action.payload,
        result: action.payload,
    });
}));
export const notebookEpics = combineEpics(runEpic, runAllEpic, interruptEpic, insertAboveEpic, insertBelowEpic, deleteEpic, changeCellTypeEpic, saveEpic);
/* Reducers */
export const notebookReducer = reducerWithInitialState(notebookInitialState)
    .case(notebookActions.reset, (state, _) => {
    return notebookInitialState;
})
    .case(notebookActions.update, (state, partialState) => {
    return Object.assign(Object.assign({}, state), partialState);
})
    .case(notebookActions.activeCellChange, (state, activeCell) => {
    return Object.assign(Object.assign({}, state), { activeCell });
})
    .case(notebookActions.modelChange, (state, model) => {
    return Object.assign(Object.assign({}, state), { model });
})
    .case(notebookActions.notebookChange, (state, notebookChange) => {
    return Object.assign(Object.assign({}, state), { notebookChange });
})
    .case(notebookActions.kernelStatusChanged, (state, kernelStatus) => {
    return Object.assign(Object.assign({}, state), { kernelStatus });
})
    .case(notebookActions.portal, (state, portal) => {
    const portals = state.portals.concat(portal);
    return Object.assign(Object.assign({}, state), { portals });
})
    .case(notebookActions.setPortals, (state, portals) => {
    return Object.assign(Object.assign({}, state), { portals });
})
    .case(notebookActions.setPortal, (state, portal) => {
    return Object.assign(Object.assign({}, state), { portal });
})
    .case(notebookActions.save.done, (state, payload) => {
    return Object.assign(Object.assign({}, state), { saveRequest: payload.result });
})
    .case(notebookActions.insertAbove.done, (state, payload) => {
    return state;
})
    .case(notebookActions.insertBelow.done, (state, payload) => {
    return state;
})
    .case(notebookActions.changeCellType.done, (state, payload) => {
    return state;
})
    .case(notebookActions.run.done, (state, _) => {
    return state;
});
//# sourceMappingURL=NotebookState.js.map