import { Fragment as _Fragment, jsx as _jsx } from "@emotion/react/jsx-runtime";
import { useState, useEffect, useRef } from 'react';
import { ReactWidget } from '@jupyterlab/apputils';
/**
 * The class name added to InputPrompt.
 */
const INPUT_PROMPT_CLASS = 'jp-InputPrompt';
const Countdown = (props) => {
    const [count, setCount] = useState(props.count);
    let intervalRef = useRef();
    const decreaseNum = () => setCount((prev) => prev - 1);
    useEffect(() => {
        setCount(props.count);
    }, [props.count]);
    useEffect(() => {
        intervalRef.current = setInterval(decreaseNum, 1000);
        return () => clearInterval(intervalRef.current);
    }, []);
    return (_jsx(_Fragment, { children: count }, void 0));
};
/**
 * The custom input prompt implementation.
 */
export class InputPrompt extends ReactWidget {
    /*
    * Create an output prompt widget.
    */
    constructor() {
        super();
        this._executionCount = null;
        this.state = {
            count: 100
        };
        this.addClass(INPUT_PROMPT_CLASS);
    }
    /** @override */
    render() {
        return _jsx(Countdown, { count: this.state.count }, void 0);
    }
    /**
     * The execution count for the prompt.
     */
    get executionCount() {
        return this._executionCount;
    }
    set executionCount(value) {
        this._executionCount = value;
        if (value === null) {
            this.state = {
                count: 0
            };
        }
        else {
            if (value === '*') {
                this.state = {
                    count: 0
                };
            }
            else {
                this.state = {
                    count: Number(value)
                };
                this.update();
            }
        }
    }
}
export default InputPrompt;
//# sourceMappingURL=InputPrompt.js.map