var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { ServerConnection, KernelManager, SessionManager } from '@jupyterlab/services';
import { UUID } from '@lumino/coreutils';
const headers = new Headers({
    "Cache-Control": "no-cache, no-store, must-revalidate",
    "Pragma": "no-cache",
    "Expires": "0",
});
export class Kernel {
    constructor(options = {}) {
        this._serverSettings = ServerConnection.makeSettings({
            baseUrl: options.baseUrl || (location.protocol + '//' + location.host + "/api/jupyter"),
            wsUrl: options.wsUrl || (location.protocol.replace('http', 'ws') + '//' + location.host + "/api/jupyter"),
            appendToken: true,
            init: {
                credentials: 'include',
                mode: 'cors',
                headers,
            }
        });
        this._kernelType = options.kernelType || 'python3';
        this._kernel = this.requestKernel();
    }
    getJupyterKernel() {
        /*
        if (this._kernel) {
          return this._kernel;
        }
        this._kernel = this.requestKernel();
        */
        return this._kernel;
    }
    requestKernel() {
        return __awaiter(this, void 0, void 0, function* () {
            const kernelManager = new KernelManager({
                serverSettings: this._serverSettings,
                standby: 'never',
            });
            const sessionManager = new SessionManager({
                serverSettings: this._serverSettings,
                kernelManager,
                standby: 'never',
            });
            yield sessionManager.ready;
            const kernelId = UUID.uuid4();
            const session = yield sessionManager.startNew({
                path: kernelId,
                name: kernelId,
                type: this._kernelType,
            });
            yield session.kernel.info;
            return session.kernel;
        });
    }
}
export default Kernel;
//# sourceMappingURL=Kernel.js.map